.. _sampling:

.. currentmodule:: torchkge.sampling

Negative Sampling
*****************

.. automodule:: torchkge.sampling.NegativeSampling

Uniform negative sampler
------------------------
.. autoclass:: torchkge.sampling.NegativeSampling.UniformNegativeSampler
   :members:

Bernoulli negative sampler
--------------------------
.. autoclass:: torchkge.sampling.NegativeSampling.BernoulliNegativeSampler
   :members:

Positional negative sampler
---------------------------
.. autoclass:: torchkge.sampling.NegativeSampling.PositionalNegativeSampler
   :members:
